/*
 *  FreqAnalyzer.cpp
 *  BeatDetection
 *
 *  Created by Serban Porumbescu on 11/8/10.
 *  Copyright 2010 Hidden Elephant Software. All rights reserved.
 *
 */

#include "FreqAnalyzer.h"
#include <iostream>

FreqAnalyzer::FreqAnalyzer()
{
   float sampleRate = 44100.0f;
   float lpCutoff = 120.0f;
   float hpCutoff = 12000.0f;
   
   // low pass
   float dt = 1.0f / sampleRate;
   float RC = 1.0f / lpCutoff;
   filterConstLP = dt / (dt + RC);
   
   // high pass
   RC = 1.0f / hpCutoff;
   filterConstHP = RC / (dt + RC);
   
   beatLP = 0.0f;
   beatHP = 0.0f;
   beatLP_level = 0.0f;
   beatHP_level = 0.0f; 
}

void FreqAnalyzer::AudioProcess (float *input, unsigned int length, 
                                 unsigned int nChannels)
{
   float a = filterConstLP;
   float b = filterConstHP;
   
   for(unsigned int i = 2; i < length; i += 2) // just left channel
   {
      // low pass
      beatLP = a * beatLP + (1.0f - a) * input[i];
      if(beatLP > beatLP_level)
         beatLP_level = beatLP;
      
      // high pass
      beatHP = b * (beatHP + input[i] - input[i-2]);
      if(beatHP > beatHP_level)
         beatHP_level = beatHP;
   }
}

void FreqAnalyzer::update()
{
   float decay = 0.9f;
   beatLP_level *= decay;
   beatHP_level *= decay;
}

