//
//  BeatDetectionViewController.h
//  BeatDetection
//
//  Created by Serban Porumbescu on 11/8/10.
//  Copyright 2010 Hidden Elephant Software. All rights reserved.
//

#import <UIKit/UIKit.h>

#import <OpenGLES/EAGL.h>

#import <OpenGLES/ES1/gl.h>
#import <OpenGLES/ES1/glext.h>
#import <OpenGLES/ES2/gl.h>
#import <OpenGLES/ES2/glext.h>

#import "fmod.hpp"
#import "fmod_errors.h"
#include "BeatDetector.h"
#include "FreqAnalyzer.h"

@interface BeatDetectionViewController : UIViewController
{
    EAGLContext *context;
    GLuint program;
    
    BOOL animating;
    BOOL displayLinkSupported;
    NSInteger animationFrameInterval;
    /*
	 Use of the CADisplayLink class is the preferred method for controlling your animation timing.
	 CADisplayLink will link to the main display and fire every vsync when added to a given run-loop.
	 The NSTimer object is used only as fallback when running on a pre-3.1 device where CADisplayLink isn't available.
	 */
    id displayLink;
    NSTimer *animationTimer;
   
   FMOD::System   *fmod_system;
   FMOD::Sound    *sound;
   FMOD::Channel  *channel;
   FMOD::DSP      *audioAnalyzerDSP;   
}

@property (readonly, nonatomic, getter=isAnimating) BOOL animating;
@property (nonatomic) NSInteger animationFrameInterval;

- (void)startAnimation;
- (void)stopAnimation;

- (void)activateAudioSystem;
- (void)deactivateAudioSystem;
- (void)setupAudioAnalyzerDSP;
- (IBAction)playSound;

@end
