//
//  FMODBasicsViewController.m
//  FMODBasics
//
//  Created by Serban Porumbescu on 11/6/10.
//  Copyright 2010 Hidden Elephant Software. All rights reserved.
//

#import "FMODBasicsViewController.h"

@implementation FMODBasicsViewController

void ERRCHECK(FMOD_RESULT result)
{
   if (result != FMOD_OK)
   {
      fprintf(stderr, "FMOD error! (%d) %s\n", result,
              FMOD_ErrorString(result));
      exit(-1);
   }
}

- (void)viewDidLoad
{
   system = NULL;
   sound = NULL;
   channel = NULL;
}

- (void)viewWillAppear:(BOOL)animated
{
   FMOD_RESULT result = FMOD_OK;
   
   // Create System object
   result = FMOD::System_Create(&system); 
   ERRCHECK(result);
   
   // Initialize System object
   result = system->init(100, FMOD_INIT_NORMAL, 0);
   ERRCHECK(result);
   
   // Load a sound
   NSString *soundPath = [NSString stringWithFormat:@"%@/swish.wav", 
                          [[NSBundle mainBundle] resourcePath]];
   result = system->createSound([soundPath UTF8String], FMOD_SOFTWARE, NULL, 
                                &sound);
   ERRCHECK(result);
   
   // Timer for our update loop
   timer = [NSTimer scheduledTimerWithTimeInterval:0.05 target:self 
                                          selector:@selector(timerUpdate:) 
                                          userInfo:nil repeats:YES];
}

- (void)timerUpdate:(NSTimer *)timer
{
   FMOD_RESULT result = FMOD_OK;

   if(NULL != system)
   {
      result = system->update();
      ERRCHECK(result);
   }
}

- (IBAction)playSound
{
   FMOD_RESULT result = FMOD_OK;
   
   result = system->playSound(FMOD_CHANNEL_FREE, sound, false, &channel);
   ERRCHECK(result); 
}

- (void)viewWillDisappear:(BOOL)animated
{
   [timer invalidate];
   
   if(sound)
   {
      sound->release();
      sound = NULL;
   }
   
   if(system)
   {
      system->release();
      system = NULL; 
   }
}

- (void)dealloc 
{
   [super dealloc];
}
@end
